Improve this Doc View Source

Specify custom behavior on keydown event.

## Directive Info

- This directive executes at priority level 0.

## Usage

- as element:

      <ng-keydown
        ng-keydown="expression">
      ...
      </ng-keydown>

- as attribute:

      <ANY
        ng-keydown="expression">
      ...
      </ANY>

### Arguments

Param | Type | Details
--- | --- | ---
ngKeydown | expression | Expression to evaluate upon keydown. (Event object is available as `$event` and can be interrogated for keyCode, altKey, etc.)

## Examples

    <input ng-keydown="count = count + 1" ng-init="count=0">
    key down count: {{count}}